@@ -1,6 +1,6 @@
 #' @rdname p_value_betwithin
 #' @export
-ci_betwithin <- function(model, ci = .95, robust = FALSE, ...) {
+ci_betwithin <- function(model, ci = 0.95, ...) {
   df_bet <- dof_ml1(model)
   out <- lapply(ci, function(i) {
     .ci_dof(
@@ -10,7 +10,6 @@ ci_betwithin <- function(model, ci = .95, robust = FALSE, ...) {
       component = "all",
       dof = df_bet,
       method = "betwithin",
-      robust = robust,
       ...
     )
   })
