@@ -2,15 +2,13 @@
 #' @name display.parameters_model
 #'
 #' @description Prints tables (i.e. data frame) in different output formats.
-#' `print_md()` is a alias for `display(format = "markdown")`, `print_html()`
-#' is a alias for `display(format = "html")`. `print_table()` is for specific
+#' `print_md()` is an alias for `display(format = "markdown")`, `print_html()`
+#' is an alias for `display(format = "html")`. `print_table()` is for specific
 #' use cases only, and currently only works for `compare_parameters()` objects.
 #'
-#' @param x An object returned by [`model_parameters()`][model_parameters].
-#' @param object An object returned by [`model_parameters()`][model_parameters],
-#' [`simulate_parameters()`][simulate_parameters],
-#' [`equivalence_test()`][equivalence_test.lm] or
-#' [`principal_components()`][principal_components].
+#' @param x An object returned by [`model_parameters()`].
+#' @param object An object returned by [`model_parameters()`],[`simulate_parameters()`],
+#' [`equivalence_test()`] or [`principal_components()`].
 #' @param format String, indicating the output format. Can be `"markdown"`
 #' or `"html"`.
 #' @param align Only applies to HTML tables. May be one of `"left"`,
@@ -53,9 +51,10 @@
 #' experimental, thus, only a fixed layout-style is available at the moment
 #' (columns for estimates, confidence intervals and p-values). However, it
 #' is possible to include other model components, like zero-inflation, or random
-#' effects in the table. See 'Examples'.
+#' effects in the table. See 'Examples'. An alternative is to set `engine = "tt"`
+#' in `print_html()` to use the _tinytable_ package for creating HTML tables.
 #'
-#' @seealso [print.parameters_model()]
+#' @seealso [print.parameters_model()] and [print.compare_parameters()]
 #'
 #' @examplesIf require("gt", quietly = TRUE)
 #' model <- lm(mpg ~ wt + cyl, data = mtcars)
@@ -114,7 +113,8 @@ display.parameters_model <- function(object,
       footer_digits = footer_digits, align = align, ci_brackets = ci_brackets,
       show_sigma = show_sigma, show_formula = show_formula, zap_small = zap_small,
       font_size = font_size, line_padding = line_padding,
-      column_labels = column_labels, verbose = verbose, ...
+      column_labels = column_labels, include_reference = include_reference,
+      verbose = verbose, ...
     )
   } else {
     print_md(
@@ -123,7 +123,7 @@ display.parameters_model <- function(object,
       footer = footer, ci_digits = ci_digits, p_digits = p_digits,
       footer_digits = footer_digits, ci_brackets = ci_brackets,
       show_sigma = show_sigma, show_formula = show_formula, zap_small = zap_small,
-      verbose = verbose, ...
+      include_reference = include_reference, verbose = verbose, ...
     )
   }
 }
@@ -135,9 +135,6 @@ display.parameters_simulate <- display.parameters_model
 display.parameters_brms_meta <- display.parameters_model
 
 
-
-
-
 # Compare Parameters ------------------------
 
 
@@ -167,9 +164,6 @@ display.compare_parameters <- function(object,
 }
 
 
-
-
-
 # SEM models ------------------------
 
 
@@ -186,9 +180,6 @@ display.parameters_sem <- function(object,
 }
 
 
-
-
-
 # PCA /EFA  models ------------------------
 
 
@@ -213,9 +204,6 @@ display.parameters_efa <- function(object, format = "markdown", digits = 2, sort
 display.parameters_pca <- display.parameters_efa
 
 
-
-
-
 # Equivalence tests ------------------------
 
 
@@ -226,8 +214,6 @@ display.equivalence_test_lm <- function(object, format = "markdown", digits = 2,
 }
 
 
-
-
 # Other functions ------------------------
 
 
