@@ -1,8 +1,8 @@
 #' @rdname p_value_betwithin
 #' @export
 dof_betwithin <- function(model) {
-  if (!insight::model_info(model, verbose = FALSE)$is_mixed) {
-    stop("Model must be a mixed model.")
+  if (!insight::is_mixed_model(model)) {
+    insight::format_error("Model must be a mixed model.")
   }
 
   ngrps <- sum(.n_randomeffects(model))
@@ -19,7 +19,7 @@ dof_betwithin <- function(model) {
   }
 
   within_index <- match(within_effects, parameters)
-  ddf <- stats::setNames(1:length(parameters), parameters)
+  ddf <- stats::setNames(seq_along(parameters), parameters)
 
   if (length(within_index) > 0) {
     ddf[match(within_effects, parameters)] <- ddf_within
