@@ -16,7 +16,7 @@
                                         keep_parameters = NULL,
                                         drop_parameters = NULL,
                                         include_sigma = TRUE,
-                                        summary = FALSE,
+                                        include_info = FALSE,
                                         vcov = NULL,
                                         vcov_args = NULL,
                                         ...) {
@@ -26,7 +26,7 @@
 
   if (isTRUE(standardize)) {
     if (verbose) {
-      insight::format_warning(
+      insight::format_alert(
         "`standardize` must be on of \"refit\", \"posthoc\", \"basic\", \"smart\" or \"pseudo\"."
       )
     }
@@ -43,12 +43,11 @@
   # ==== for refit, we completely refit the model, than extract parameters, ci etc. as usual
 
   if (isTRUE(standardize == "refit")) {
-    args <- list(model, verbose = FALSE)
-    args <- c(args, list(...))
+    fun_args <- c(list(model, verbose = FALSE), dots)
     # argument name conflict with deprecated `robust`
-    args[["robust"]] <- NULL
+    fun_args[["robust"]] <- NULL
     fun <- datawizard::standardize
-    model <- do.call(fun, args)
+    model <- do.call(fun, fun_args)
   }
 
   parameters <- insight::get_parameters(model,
@@ -59,7 +58,7 @@
   statistic <- insight::get_statistic(model, component = component)
 
   # check if all estimates are non-NA
-  parameters <- .check_rank_deficiency(parameters)
+  parameters <- .check_rank_deficiency(model, parameters)
 
 
   # ==== check if we really have a component column
@@ -80,7 +79,7 @@
   #      intercepts (alpha-coefficients) in the component column
 
   if (inherits(model, "polr")) {
-    intercept_groups <- which(grepl("Intercept:", parameters$Parameter, fixed = TRUE))
+    intercept_groups <- grep("Intercept:", parameters$Parameter, fixed = TRUE)
     parameters$Parameter <- gsub("Intercept: ", "", parameters$Parameter, fixed = TRUE)
   } else if (inherits(model, "clm") && !is.null(model$alpha)) {
     intercept_groups <- rep(
@@ -92,6 +91,9 @@
       c("intercept", "location", "scale"),
       lengths(model[c("Alpha", "beta", "zeta")])
     )
+  } else if (inherits(model, "ordinal_weightit")) {
+    intercept_groups <- rep("conditional", nrow(parameters))
+    intercept_groups[grep("|", parameters$Parameter, fixed = TRUE)] <- "intercept"
   } else {
     intercept_groups <- NULL
   }
@@ -104,20 +106,23 @@
 
   # ==== CI - only if we don't already have CI for std. parameters
 
+  ci_cols <- NULL
   if (!is.null(ci)) {
-    args <- list(model,
+    # set up arguments for CI function
+    fun_args <- list(model,
       ci = ci,
       component = component,
       vcov = vcov,
       vcov_args = vcov_args,
       verbose = verbose
     )
-    args <- c(args, dots)
+    fun_args <- c(fun_args, dots)
+    # add method argument if provided
     if (!is.null(ci_method)) {
-      args[["method"]] <- ci_method
+      fun_args[["method"]] <- ci_method
     }
-    ci_df <- suppressMessages(do.call("ci", args))
-
+    ci_df <- suppressMessages(do.call("ci", fun_args))
+    # success? merge CI into parameters
     if (!is.null(ci_df)) {
       # for multiple CI columns, reshape CI-dataframe to match parameters df
       if (length(ci) > 1) {
@@ -126,17 +131,13 @@
       # remember names of CI columns, used for later sorting of columns
       ci_cols <- names(ci_df)[!names(ci_df) %in% c("CI", merge_by)]
       parameters <- merge(parameters, ci_df, by = merge_by, sort = FALSE)
-    } else {
-      ci_cols <- NULL
     }
-  } else {
-    ci_cols <- NULL
   }
 
 
   # ==== p value
 
-  args <- list(model,
+  fun_args <- list(model,
     method = ci_method,
     effects = effects,
     verbose = verbose,
@@ -144,9 +145,9 @@
     vcov = vcov,
     vcov_args = vcov_args
   )
-  args <- c(args, dots)
-  pval <- do.call("p_value", args)
-
+  fun_args <- c(fun_args, dots)
+  pval <- do.call("p_value", fun_args)
+  # success? merge p-values into parameters
   if (!is.null(pval)) {
     parameters <- merge(parameters, pval, by = merge_by, sort = FALSE)
   }
@@ -155,19 +156,19 @@
   # ==== standard error - only if we don't already have SE for std. parameters
 
   std_err <- NULL
-  args <- list(model,
+  fun_args <- list(model,
     effects = effects,
     component = component,
     verbose = verbose,
     vcov = vcov,
     vcov_args = vcov_args
   )
-  args <- c(args, dots)
+  fun_args <- c(fun_args, dots)
   if (!is.null(ci_method)) {
-    args[["method"]] <- ci_method
+    fun_args[["method"]] <- ci_method
   }
-  std_err <- do.call("standard_error", args)
-
+  std_err <- do.call("standard_error", fun_args)
+  # success? merge SE into parameters
   if (!is.null(std_err)) {
     parameters <- merge(parameters, std_err, by = merge_by, sort = FALSE)
   }
@@ -175,9 +176,7 @@
 
   # ==== test statistic - fix values for robust vcov
 
-
-  # deprecated argument `robust = TRUE`
-  if (!is.null(vcov) || isTRUE(dots[["robust"]])) {
+  if (!is.null(vcov)) {
     parameters$Statistic <- parameters$Estimate / parameters$SE
   } else if (!is.null(statistic)) {
     parameters <- merge(parameters, statistic, by = merge_by, sort = FALSE)
@@ -186,10 +185,10 @@
 
   # ==== degrees of freedom
 
-  if (!is.null(ci_method)) {
-    df_error <- degrees_of_freedom(model, method = ci_method, verbose = FALSE)
+  if (is.null(ci_method)) {
+    df_error <- insight::get_df(x = model, type = "wald", verbose = FALSE)
   } else {
-    df_error <- degrees_of_freedom(model, method = "any", verbose = FALSE)
+    df_error <- insight::get_df(x = model, type = ci_method, verbose = FALSE)
   }
   if (!is.null(df_error) && (length(df_error) == 1 || length(df_error) == nrow(parameters))) {
     if (length(df_error) == 1) {
@@ -225,15 +224,15 @@
   if (inherits(model, "polr") && !is.null(intercept_groups)) {
     parameters$Component <- "beta"
     parameters$Component[intercept_groups] <- "alpha"
-  } else if (inherits(model, c("clm", "clm2")) && !is.null(intercept_groups)) {
+  } else if (inherits(model, c("clm", "clm2", "ordinal_weightit")) && !is.null(intercept_groups)) {
     parameters$Component <- intercept_groups
   }
 
 
   # ==== remove Component column if not needed
 
-  if (!is.null(parameters$Component) && insight::n_unique(parameters$Component) == 1 && !keep_component_column) parameters$Component <- NULL
-  if ((!is.null(parameters$Effects) && insight::n_unique(parameters$Effects) == 1) || effects == "fixed") parameters$Effects <- NULL
+  if (!is.null(parameters$Component) && insight::n_unique(parameters$Component) == 1 && !keep_component_column) parameters$Component <- NULL # nolint
+  if ((!is.null(parameters$Effects) && insight::n_unique(parameters$Effects) == 1) || effects == "fixed") parameters$Effects <- NULL # nolint
 
 
   # ==== filter parameters, if requested
@@ -301,7 +300,7 @@
 
   # ==== add sigma and residual df
 
-  if (isTRUE(include_sigma) || isTRUE(summary)) {
+  if (isTRUE(include_sigma) || isTRUE(include_info)) {
     parameters <- .add_sigma_residual_df(parameters, model)
   }
 
@@ -316,21 +315,16 @@
 
 .add_sigma_residual_df <- function(params, model) {
   if (is.null(params$Component) || !"sigma" %in% params$Component) {
-    sig <- tryCatch(suppressWarnings(insight::get_sigma(model, ci = NULL, verbose = FALSE)),
-      error = function(e) NULL
-    )
+    sig <- .safe(suppressWarnings(insight::get_sigma(model, ci = NULL, verbose = FALSE)))
     attr(params, "sigma") <- as.numeric(sig)
 
-    resdf <- tryCatch(suppressWarnings(insight::get_df(model, type = "residual")),
-      error = function(e) NULL
-    )
+    resdf <- .safe(suppressWarnings(insight::get_df(x = model, type = "residual")))
     attr(params, "residual_df") <- as.numeric(resdf)
   }
   params
 }
 
 
-
 .filter_parameters <- function(params, keep = NULL, drop = NULL, verbose = TRUE) {
   if (!is.null(keep) && is.list(keep)) {
     for (i in names(keep)) {
@@ -360,7 +354,7 @@
                                       verbose = TRUE) {
   # check pattern
   if (!is.null(keep) && length(keep) > 1) {
-    keep <- paste0("(", paste0(keep, collapse = "|"), ")")
+    keep <- paste0("(", paste(keep, collapse = "|"), ")")
     if (verbose) {
       insight::format_alert(
         sprintf("The `keep` argument has more than 1 element. Merging into following regular expression: `%s`.", keep)
@@ -370,7 +364,7 @@
 
   # check pattern
   if (!is.null(drop) && length(drop) > 1) {
-    drop <- paste0("(", paste0(drop, collapse = "|"), ")")
+    drop <- paste0("(", paste(drop, collapse = "|"), ")")
     if (verbose) {
       insight::format_alert(
         sprintf("The `drop` argument has more than 1 element. Merging into following regular expression: `%s`.", drop)
@@ -387,16 +381,16 @@
   }
 
   # row to keep and drop
-  if (!is.null(keep)) {
-    rows_to_keep <- grepl(keep, params[[column]], perl = TRUE)
-  } else {
+  if (is.null(keep)) {
     rows_to_keep <- rep_len(TRUE, nrow(params))
+  } else {
+    rows_to_keep <- grepl(keep, params[[column]], perl = TRUE)
   }
 
-  if (!is.null(drop)) {
-    rows_to_drop <- !grepl(drop, params[[column]], perl = TRUE)
-  } else {
+  if (is.null(drop)) {
     rows_to_drop <- rep_len(TRUE, nrow(params))
+  } else {
+    rows_to_drop <- !grepl(drop, params[[column]], perl = TRUE)
   }
 
 
@@ -404,8 +398,8 @@
 
   if (nrow(out) == 0) {
     if (verbose) {
-      insight::format_warning(
-        "The pattern defined in the `keep` (and `drop`) arguments would remove all parameters from the output. Thus, selecting specific parameters will be ignored."
+      insight::format_alert(
+        "The pattern defined in the `keep` (and `drop`) arguments would remove all parameters from the output. Thus, selecting specific parameters will be ignored." # nolint
       )
     }
     return(params)
@@ -428,7 +422,7 @@
                                       keep_parameters = NULL,
                                       drop_parameters = NULL,
                                       include_sigma = FALSE,
-                                      summary = FALSE,
+                                      include_info = FALSE,
                                       vcov = NULL,
                                       vcov_args = NULL,
                                       verbose = TRUE,
@@ -442,7 +436,7 @@
   statistic <- insight::get_statistic(model, component = "all")
 
   # check if all estimates are non-NA
-  parameters <- .check_rank_deficiency(parameters)
+  parameters <- .check_rank_deficiency(model, parameters)
 
   # sometimes, due to merge(), row-order messes up, so we save this here
   original_order <- parameters$.id <- seq_len(nrow(parameters))
@@ -456,57 +450,58 @@
 
   # Degrees of freedom
   if (.dof_method_ok(model, ci_method)) {
-    df <- degrees_of_freedom(model, method = ci_method, verbose = FALSE)
+    dof <- insight::get_df(x = model, type = ci_method, verbose = FALSE)
   } else {
-    df <- Inf
+    dof <- Inf
   }
 
   df_error <- data.frame(
     Parameter = parameters$Parameter,
-    df_error = as.vector(df),
+    df_error = as.vector(dof),
     stringsAsFactors = FALSE
   )
   # for KR-dof, we have the SE as well, to save computation time
-  df_error$SE <- attr(df, "se", exact = TRUE)
+  df_error$SE <- attr(dof, "se", exact = TRUE)
 
 
   # CI - only if we don't already have CI for std. parameters
 
+  ci_cols <- NULL
   if (!is.null(ci)) {
     # robust (current or deprecated)
     if (!is.null(vcov) || isTRUE(list(...)[["robust"]])) {
-      args <- list(model,
+      fun_args <- list(model,
         ci = ci,
         vcov = vcov,
         vcov_args = vcov_args,
         verbose = verbose
       )
-      args <- c(args, dots)
-      ci_df <- suppressMessages(do.call("ci", args))
+      fun_args <- c(fun_args, dots)
+      ci_df <- suppressMessages(do.call("ci", fun_args))
     } else if (ci_method %in% c("kenward", "kr")) {
       # special handling for KR-CIs, where we already have computed SE
       ci_df <- .ci_kenward_dof(model, ci = ci, df_kr = df_error)
     } else {
       ci_df <- ci(model, ci = ci, method = ci_method, effects = "fixed")
     }
-    if (length(ci) > 1) ci_df <- datawizard::reshape_ci(ci_df)
+    if (length(ci) > 1) {
+      ci_df <- datawizard::reshape_ci(ci_df)
+    }
     ci_cols <- names(ci_df)[!names(ci_df) %in% c("CI", "Parameter")]
     parameters <- merge(parameters, ci_df, by = "Parameter", sort = FALSE)
-  } else {
-    ci_cols <- NULL
   }
 
 
   # standard error - only if we don't already have SE for std. parameters
   if (!"SE" %in% colnames(parameters)) {
     if (!is.null(vcov) || isTRUE(dots[["robust"]])) {
-      args <- list(model,
+      fun_args <- list(model,
         vcov = vcov,
         vcov_args = vcov_args,
         verbose = verbose
       )
-      args <- c(args, dots)
-      parameters <- merge(parameters, do.call("standard_error", args), by = "Parameter", sort = FALSE)
+      fun_args <- c(fun_args, dots)
+      parameters <- merge(parameters, do.call("standard_error", fun_args), by = "Parameter", sort = FALSE)
       # special handling for KR-SEs, which we already have computed from dof
     } else if ("SE" %in% colnames(df_error)) {
       se_kr <- df_error
@@ -525,33 +520,31 @@
 
   # p value
   if (!is.null(vcov) || isTRUE(list(...)[["robust"]])) {
-    args <- list(model,
+    fun_args <- list(model,
       vcov = vcov,
       vcov_args = vcov_args,
       verbose = verbose
     )
-    args <- c(args, dots)
-    parameters <- merge(parameters, do.call("p_value", args), by = "Parameter", sort = FALSE)
+    fun_args <- c(fun_args, dots)
+    parameters <- merge(parameters, do.call("p_value", fun_args), by = "Parameter", sort = FALSE)
+  } else if ("Pr(>|z|)" %in% names(parameters)) {
+    names(parameters)[grepl("Pr(>|z|)", names(parameters), fixed = TRUE)] <- "p"
+  } else if (ci_method %in% special_ci_methods) {
+    # special handling for KR-p, which we already have computed from dof
+    # parameters <- merge(parameters, .p_value_dof_kr(model, params = parameters, dof = df_error), by = "Parameter")
+    parameters <- merge(
+      parameters,
+      .p_value_dof(model, dof = df_error$df_error, method = ci_method, se = df_error$SE),
+      by = "Parameter",
+      sort = FALSE
+    )
   } else {
-    if ("Pr(>|z|)" %in% names(parameters)) {
-      names(parameters)[grepl("Pr(>|z|)", names(parameters), fixed = TRUE)] <- "p"
-    } else if (ci_method %in% special_ci_methods) {
-      # special handling for KR-p, which we already have computed from dof
-      # parameters <- merge(parameters, .p_value_dof_kr(model, params = parameters, dof = df_error), by = "Parameter")
-      parameters <- merge(
-        parameters,
-        .p_value_dof(model, dof = df_error$df_error, method = ci_method, se = df_error$SE),
-        by = "Parameter",
-        sort = FALSE
-      )
-    } else {
-      parameters <- merge(
-        parameters,
-        p_value(model, dof = df, effects = "fixed"),
-        by = "Parameter",
-        sort = FALSE
-      )
-    }
+    parameters <- merge(
+      parameters,
+      p_value(model, dof = dof, effects = "fixed"),
+      by = "Parameter",
+      sort = FALSE
+    )
   }
 
 
@@ -570,7 +563,7 @@
     if (!ci_method %in% special_ci_methods) {
       df_error <- data.frame(
         Parameter = parameters$Parameter,
-        df_error = degrees_of_freedom(model, method = "any"),
+        df_error = insight::get_df(x = model, type = "wald"),
         stringsAsFactors = FALSE
       )
     }
@@ -639,12 +632,12 @@
   }
 
   # Reorder
-  order <- c("Parameter", coef_col, "SE", ci_cols, "t", "z", "df", "df_error", "p", "Component")
-  parameters <- parameters[order[order %in% names(parameters)]]
+  col_order <- c("Parameter", coef_col, "SE", ci_cols, "t", "z", "df", "df_error", "p", "Component")
+  parameters <- parameters[col_order[col_order %in% names(parameters)]]
 
 
   # add sigma
-  if (isTRUE(include_sigma) || isTRUE(summary)) {
+  if (isTRUE(include_sigma) || isTRUE(include_info)) {
     parameters <- .add_sigma_residual_df(parameters, model)
   }
 
@@ -654,7 +647,6 @@
 }
 
 
-
 .add_within_between_effects <- function(model, parameters) {
   # This function checks whether the model contains predictors that were
   # "demeaned" using the "demean()" function. If so, these columns have an
@@ -681,7 +673,7 @@
       grep,
       x = parameters$Parameter,
       fixed = TRUE
-    )))
+    ), use.names = FALSE))
     parameters$Component[index] <- "within"
   }
 
@@ -691,7 +683,7 @@
       grep,
       x = parameters$Parameter,
       fixed = TRUE
-    )))
+    ), use.names = FALSE))
     parameters$Component[index] <- "between"
   }
 
@@ -709,21 +701,16 @@
 }
 
 
-
 .find_within_between <- function(model, which_effect) {
   mf <- stats::model.frame(model)
   unlist(sapply(names(mf), function(i) {
     if (!is.null(attr(mf[[i]], which_effect, exact = TRUE))) {
       i
     }
-  }))
+  }), use.names = FALSE)
 }
 
 
-
-
-
-
 # Bayes function ------------------------------------------------------
 
 
@@ -745,11 +732,13 @@
                                          verbose = TRUE,
                                          ...) {
   # no ROPE for multi-response models
-  if (insight::is_multivariate(model)) {
+  if (insight::is_multivariate(model) && any(c("rope", "p_rope") %in% test)) {
     test <- setdiff(test, c("rope", "p_rope"))
-    insight::format_warning(
-      "Multivariate response models are not yet supported for tests `rope` and `p_rope`."
-    )
+    if (verbose) {
+      insight::format_alert(
+        "Multivariate response models are not yet supported for tests `rope` and `p_rope`."
+      )
+    }
   }
 
   # MCMCglmm need special handling
@@ -767,7 +756,23 @@
       verbose = verbose,
       ...
     )
-  } else if (!is.null(standardize)) {
+  } else if (is.null(standardize)) {
+    parameters <- bayestestR::describe_posterior(
+      model,
+      centrality = centrality,
+      dispersion = dispersion,
+      ci = ci,
+      ci_method = ci_method,
+      test = test,
+      rope_range = rope_range,
+      rope_ci = rope_ci,
+      bf_prior = bf_prior,
+      diagnostic = diagnostic,
+      priors = priors,
+      verbose = verbose,
+      ...
+    )
+  } else {
     parameters <- bayestestR::describe_posterior(
       model,
       centrality = centrality,
@@ -806,22 +811,6 @@
       parameters[c("Parameter", setdiff(colnames(parameters), colnames(std_parameters)))],
       sort = FALSE
     )
-  } else {
-    parameters <- bayestestR::describe_posterior(
-      model,
-      centrality = centrality,
-      dispersion = dispersion,
-      ci = ci,
-      ci_method = ci_method,
-      test = test,
-      rope_range = rope_range,
-      rope_ci = rope_ci,
-      bf_prior = bf_prior,
-      diagnostic = diagnostic,
-      priors = priors,
-      verbose = verbose,
-      ...
-    )
   }
 
   if (length(ci) > 1) {
@@ -850,13 +839,13 @@
   }
 
   rownames(parameters) <- NULL
+  # indicate it's a Bayesian model
+  attr(parameters, "is_bayesian") <- TRUE
+
   parameters
 }
 
 
-
-
-
 # SEM function ------------------------------------------------------
 
 
@@ -887,8 +876,8 @@
   valid_std_options <- c("all", "std.all", "latent", "std.lv", "no_exogenous", "std.nox")
   if (!is.logical(standardize) && !(standardize %in% valid_std_options)) {
     if (verbose) {
-      insight::format_warning(
-        "`standardize` should be one of `TRUE`, \"all\", \"std.all\", \"latent\", \"std.lv\", \"no_exogenous\" or \"std.nox\".",
+      insight::format_alert(
+        "`standardize` should be one of `TRUE`, \"all\", \"std.all\", \"latent\", \"std.lv\", \"no_exogenous\" or \"std.nox\".", # nolint
         "Returning unstandardized solution."
       )
     }
@@ -899,7 +888,7 @@
   if (length(ci) > 1L) {
     ci <- ci[1]
     if (verbose) {
-      insight::format_warning(
+      insight::format_alert(
         paste0("lavaan models only accept one level of CI. Keeping the first one: `ci = ", ci, "`.")
       )
     }
@@ -930,7 +919,7 @@
   )]
 
   # Get estimates
-  data <- do.call(
+  sem_data <- do.call(
     lavaan::parameterEstimates,
     c(
       list(object = model, se = TRUE, ci = TRUE, level = ci),
@@ -938,7 +927,7 @@
     )
   )
 
-  label <- data$label
+  label <- sem_data$label
 
   # check if standardized estimates are requested, and if so, which type
   if (isTRUE(standardize) || !is.logical(standardize)) {
@@ -947,12 +936,12 @@
     }
 
     type <- switch(standardize,
-      "all" = ,
-      "std.all" = "std.all",
-      "latent" = ,
-      "std.lv" = "std.lv",
-      "no_exogenous" = ,
-      "std.nox" = "std.nox",
+      all = ,
+      std.all = "std.all",
+      latent = ,
+      std.lv = "std.lv",
+      no_exogenous = ,
+      std.nox = "std.nox",
       "std.all"
     )
 
@@ -960,23 +949,23 @@
     valid <- names(formals(lavaan::standardizedsolution))
     dots <- list(...)
     dots <- dots[names(dots) %in% valid]
-    args <- c(list(model, se = TRUE, level = ci, type = type), dots)
+    fun_args <- c(list(model, se = TRUE, level = ci, type = type), dots)
     f <- utils::getFromNamespace("standardizedsolution", "lavaan")
-    data <- do.call("f", args)
-    names(data)[names(data) == "est.std"] <- "est"
+    sem_data <- do.call("f", fun_args)
+    names(sem_data)[names(sem_data) == "est.std"] <- "est"
   }
 
 
   params <- data.frame(
-    To = data$lhs,
-    Operator = data$op,
-    From = data$rhs,
-    Coefficient = data$est,
-    SE = data$se,
-    CI_low = data$ci.lower,
-    CI_high = data$ci.upper,
-    z = data$z,
-    p = data$pvalue,
+    To = sem_data$lhs,
+    Operator = sem_data$op,
+    From = sem_data$rhs,
+    Coefficient = sem_data$est,
+    SE = sem_data$se,
+    CI_low = sem_data$ci.lower,
+    CI_high = sem_data$ci.upper,
+    z = sem_data$z,
+    p = sem_data$pvalue,
     stringsAsFactors = FALSE
   )
 
@@ -997,8 +986,8 @@
     params$p[is.na(params$p)] <- 0
   }
 
-  if ("group" %in% names(data)) {
-    params$Group <- data$group
+  if ("group" %in% names(sem_data)) {
+    params$Group <- sem_data$group
   }
 
   # filter parameters, if requested
@@ -1014,14 +1003,18 @@
 }
 
 
-
 # tools -------------------------
 
 
-.check_rank_deficiency <- function(p, verbose = TRUE) {
+.check_rank_deficiency <- function(model, p, verbose = TRUE) {
+  # for cox-panel models, we have non-linear parameters with NA coefficient,
+  # but test statistic and p-value - don't check for NA estimates in this case
+  if (!is.null(model) && inherits(model, "coxph.penal")) {
+    return(p)
+  }
   if (anyNA(p$Estimate)) {
     if (isTRUE(verbose)) {
-      insight::format_warning(
+      insight::format_alert(
         sprintf(
           "Model matrix is rank deficient. Parameters `%s` were not estimable.",
           toString(p$Parameter[is.na(p$Estimate)])
