@@ -12,7 +12,6 @@ factor_analysis <- function(x,
 }
 
 
-
 #' @export
 factor_analysis.data.frame <- function(x,
                                        n = "auto",
@@ -22,10 +21,9 @@ factor_analysis.data.frame <- function(x,
                                        standardize = TRUE,
                                        cor = NULL,
                                        ...) {
-
   # Standardize
   if (standardize && is.null(cor)) {
-    x <- as.data.frame(scale(x))
+    x <- datawizard::standardize(x, ...)
   }
 
   # N factors
@@ -43,7 +41,6 @@ factor_analysis.data.frame <- function(x,
 }
 
 
-
 #' @keywords internal
 .factor_analysis_rotate <- function(x,
                                     n,
@@ -52,21 +49,23 @@ factor_analysis.data.frame <- function(x,
                                     threshold = NULL,
                                     cor = NULL,
                                     ...) {
-  if (!(rotation %in% c("varimax", "quartimax", "promax", "oblimin", "simplimax", "cluster", "none"))) {
-    stop("`rotation` must be one of \"varimax\", \"quartimax\", \"promax\", \"oblimin\", \"simplimax\", \"cluster\" or \"none\".")
-  }
-
   if (!inherits(x, "data.frame")) {
-    stop("`x` must be a data frame.", call. = FALSE)
+    insight::format_error("`x` must be a data frame.")
   }
 
   # rotate loadings
   if (!requireNamespace("psych", quietly = TRUE)) {
-    stop(sprintf("Package `psych` required for `%s`-rotation.", rotation), call. = FALSE)
+    insight::format_error(sprintf("Package `psych` required for `%s`-rotation.", rotation))
   }
 
   # Pass cor if available
-  if (!is.null(cor)) {
+  if (is.null(cor)) {
+    out <- model_parameters(
+      psych::fa(x, nfactors = n, rotate = rotation, ...),
+      sort = sort,
+      threshold = threshold
+    )
+  } else {
     out <- model_parameters(
       psych::fa(
         cor,
@@ -78,14 +77,8 @@ factor_analysis.data.frame <- function(x,
       sort = sort,
       threshold = threshold
     )
-  } else {
-    out <- model_parameters(
-      psych::fa(x, nfactors = n, rotate = rotation, ...),
-      sort = sort,
-      threshold = threshold
-    )
   }
 
-  attr(out, "data_set") <- x
+  attr(out, "dataset") <- x
   out
 }
