@@ -11,7 +11,7 @@
 #' @section Interpretation of Interaction Terms:
 #' Note that the *interpretation* of interaction terms depends on many
 #' characteristics of the model. The number of parameters, and overall
-#' performance of the model, can differ *or not* between `a * b`
+#' performance of the model, can differ *or not* between `a * b`,
 #' `a : b`, and `a / b`, suggesting that sometimes interaction terms
 #' give different parameterizations of the same model, but other times it gives
 #' completely different models (depending on `a` or `b` being factors
@@ -62,8 +62,6 @@ format_parameters.parameters_model <- function(model, ...) {
 }
 
 
-
-
 # Utilities ---------------------------------------------------------------
 
 
@@ -365,7 +363,6 @@ format_parameters.parameters_model <- function(model, ...) {
 }
 
 
-
 # replace pretty names with value labels, when present ---------------
 
 .format_value_labels <- function(params, model = NULL) {
@@ -412,6 +409,9 @@ format_parameters.parameters_model <- function(model, ...) {
 
     # coefficient names (not labels)
     preds <- lapply(colnames(mf), function(i) {
+      if (is.character(mf[[i]])) {
+        mf[[i]] <- as.factor(mf[[i]])
+      }
       if (is.factor(mf[[i]])) {
         i <- paste0(i, levels(mf[[i]]))
       }
