@@ -218,7 +218,6 @@ p_value.aov <- function(model, ...) {
 }
 
 
-
 # .anova ------
 
 #' @export
@@ -231,7 +230,6 @@ p_value.anova <- p_value.aov
 model_parameters.anova <- model_parameters.aov
 
 
-
 # .aov.list  ------
 
 #' @export
@@ -244,10 +242,8 @@ p_value.aovlist <- p_value.aov
 model_parameters.aovlist <- model_parameters.aov
 
 
-
 # .afex_aov  ------
 
-#' @rdname model_parameters.aov
 #' @export
 model_parameters.afex_aov <- function(model,
                                       es_type = NULL,
@@ -300,7 +296,6 @@ model_parameters.afex_aov <- function(model,
 }
 
 
-
 # others  ------
 
 #' @export
@@ -312,6 +307,9 @@ model_parameters.Anova.mlm <- model_parameters.aov
 #' @export
 model_parameters.maov <- model_parameters.aov
 
+#' @export
+model_parameters.seqanova.svyglm <- model_parameters.aov
+
 
 # helper ------------------------------
 
@@ -362,7 +360,10 @@ model_parameters.maov <- model_parameters.aov
 .anova_alternative <- function(params, alternative) {
   alternative_footer <- NULL
   if (!is.null(alternative)) {
-    alternative <- match.arg(tolower(alternative), choices = c("two.sided", "greater", "less"))
+    alternative <- insight::validate_argument(
+      tolower(alternative),
+      c("two.sided", "greater", "less")
+    )
     if (alternative != "two.sided") {
       ci_low <- which(endsWith(colnames(params), "CI_low"))
       ci_high <- which(endsWith(colnames(params), "CI_high"))
@@ -480,8 +481,6 @@ model_parameters.maov <- model_parameters.aov
 }
 
 
-
-
 # internals --------------------------
 
 # add effect size column and related CI to the parameters
@@ -533,12 +532,12 @@ model_parameters.maov <- model_parameters.aov
 .anova_table_wide <- function(data, ...) {
   wide_anova <- function(x) {
     # creating numerator and denominator degrees of freedom
-    idxResid <- x$Parameter == "Residuals"
+    idxResid <- which(x$Parameter == "Residuals")
     if (length(idxResid)) {
       x$df_error <- x$df[idxResid]
       x$Sum_Squares_Error <- x$Sum_Squares[idxResid]
-      x$Mean_Square_Error <- x$Sum_Squares[idxResid]
-      x <- x[!idxResid, ]
+      x$Mean_Square_Error <- x$Mean_Square[idxResid]
+      x <- x[-idxResid, ]
     }
     x
   }
@@ -546,6 +545,12 @@ model_parameters.maov <- model_parameters.aov
   if ("Group" %in% colnames(data)) {
     data <- split(data, data$Group)
     data <- lapply(data, wide_anova)
+    data <- Filter(function(x) nrow(x) >= 1L, data)
+    cols <- unique(unlist(lapply(data, colnames)))
+    data <- lapply(data, function(x) {
+      x[, setdiff(cols, colnames(x))] <- NA
+      x
+    })
     data <- do.call(rbind, data)
   } else {
     data <- wide_anova(data)
