@@ -22,7 +22,7 @@ model_parameters.hglm <- function(model,
                                   effects = "all",
                                   component = "all",
                                   p_adjust = NULL,
-                                  summary = getOption("parameters_summary", FALSE),
+                                  include_info = getOption("parameters_info", FALSE),
                                   keep = NULL,
                                   drop = NULL,
                                   verbose = TRUE,
@@ -37,7 +37,7 @@ model_parameters.hglm <- function(model,
     model,
     ci = ci, ci_method = ci_method, bootstrap = bootstrap,
     effects = "fixed", component = "conditional", iterations = iterations,
-    exponentiate = exponentiate, p_adjust = p_adjust, summary = summary,
+    exponentiate = exponentiate, p_adjust = p_adjust, include_info = include_info,
     keep = keep, drop = drop, verbose = verbose, ...
   )
 
@@ -67,7 +67,7 @@ model_parameters.hglm <- function(model,
 
   # add dispersion model
 
-  has_dispersion <- !is.null(insight::find_formula(model)$dispersion)
+  has_dispersion <- !is.null(insight::find_formula(model, verbose = FALSE)$dispersion)
   if (has_dispersion && component %in% c("all", "dispersion")) {
     disp_params <- insight::get_parameters(model, effects = "fixed", component = "dispersion")
     disp_se <- standard_error(model, effects = "fixed", component = "dispersion")
@@ -107,7 +107,7 @@ standard_error.hglm <- function(model,
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
   component <- match.arg(component, choices = c("all", "conditional", "dispersion"))
 
-  f <- insight::find_formula(model)
+  f <- insight::find_formula(model, verbose = FALSE)
   if (component == "dispersion" && is.null(f$dispersion)) {
     if (verbose) {
       insight::format_alert("No standard errors found for model's dispersion parameters.")
