@@ -3,17 +3,19 @@
 
 # model_parameters ----------------
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.marginaleffects <- function(model,
                                              ci = 0.95,
                                              exponentiate = FALSE,
                                              ...) {
   insight::check_if_installed("marginaleffects")
-  out <- insight::standardize_names(
-    marginaleffects::tidy(model, conf_level = ci, ...),
-    style = "easystats"
-  )
+
+  tidy_model <- marginaleffects::tidy(model, conf_level = ci, ...)
+  out <- .rename_reserved_marginaleffects(tidy_model)
+  out <- insight::standardize_names(out, style = "easystats")
+  # in case data grid contained column names that are reserved words,
+  # rename those back now...
+  colnames(out) <- gsub("#####$", "", colnames(out))
 
   # contrast_ columns provide indispensable information about the comparisons
   colnames(out)[colnames(out) == "contrast"] <- "Comparison"
@@ -23,6 +25,9 @@ model_parameters.marginaleffects <- function(model,
 
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
 
+  # do not print or report these columns
+  out <- out[, !colnames(out) %in% c("predicted_lo", "predicted_hi"), drop = FALSE]
+
   if (inherits(model, "marginalmeans")) {
     attr(out, "coefficient_name") <- "Marginal Means"
   } else if (inherits(model, "comparisons")) {
@@ -42,6 +47,15 @@ model_parameters.marginaleffects <- function(model,
   # exponentiate coefficients and SE/CI, if requested
   out <- .exponentiate_parameters(out, model = NULL, exponentiate)
 
+  # add further information as attributes
+  out <- .add_model_parameters_attributes(
+    out,
+    model = model,
+    ci = ci,
+    exponentiate = exponentiate,
+    ...
+  )
+
   class(out) <- c("parameters_model", "see_parameters_model", class(out))
   out
 }
@@ -69,10 +83,14 @@ model_parameters.predictions <- function(model,
                                          ...) {
   insight::check_if_installed("marginaleffects")
 
-  out <- datawizard::data_rename(model, "estimate", "predicted")
+  out <- .rename_reserved_marginaleffects(model)
+  out <- datawizard::data_rename(out, "estimate", "predicted")
   out <- datawizard::data_relocate(out, "predicted", before = 1)
   out <- insight::standardize_names(out, style = "easystats")
   out <- insight::standardize_column_order(out, style = "easystats")
+  # in case data grid contained column names that are reserved words,
+  # rename those back now...
+  colnames(out) <- gsub("#####$", "", colnames(out))
 
   # remove and reorder some columns
   out$rowid <- out$Type <- NULL
@@ -94,6 +112,35 @@ model_parameters.predictions <- function(model,
   # exponentiate coefficients and SE/CI, if requested
   out <- .exponentiate_parameters(out, model = NULL, exponentiate)
 
+  # add further information as attributes
+  out <- .add_model_parameters_attributes(
+    out,
+    model = model,
+    ci = ci,
+    exponentiate = exponentiate,
+    ...
+  )
+
   class(out) <- c("parameters_model", "see_parameters_model", class(out))
   out
 }
+
+
+.rename_reserved_marginaleffects <- function(model) {
+  # get focal terms - we might escape column names where focal terms
+  # equal "reserved" names, like t- or z-statistic
+  focal_terms <- attributes(model)$focal_terms
+  reserved <- c("t", "z")
+  renamed_focal <- NULL
+
+  # any focal terms equals reserved words? if so, rename
+  if (any(reserved %in% focal_terms)) {
+    renamed_focal <- focal_terms[focal_terms %in% reserved]
+    model <- datawizard::data_rename(
+      model,
+      select = renamed_focal,
+      replacement = paste0(renamed_focal, "#####")
+    )
+  }
+  model
+}
