@@ -4,7 +4,6 @@
 ###### .metaplus -------------------
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.metaplus <- function(model,
                                       ci = 0.95,
@@ -143,12 +142,9 @@ ci.metaplus <- function(x, ...) {
 }
 
 
-
-
 ###### .meta_random -------------------
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.meta_random <- function(model,
                                          ci = 0.95,
@@ -286,8 +282,6 @@ ci.meta_random <- function(x, method = "eti", ...) {
 }
 
 
-
-
 ###### .meta_fixed -------------------
 
 #' @export
@@ -302,12 +296,9 @@ standard_error.meta_fixed <- standard_error.meta_random
 ci.meta_fixed <- ci.meta_random
 
 
-
-
 ###### .meta_bma -------------------
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.meta_bma <- function(model,
                                       ci = 0.95,
@@ -318,7 +309,7 @@ model_parameters.meta_bma <- function(model,
                                       ...) {
   # process arguments
   params <- as.data.frame(model$estimates)
-  ci_method <- match.arg(ci_method, choices = c("hdi", "eti", "quantile"))
+  ci_method <- insight::validate_argument(ci_method, c("hdi", "eti", "quantile"))
 
   # parameters of studies included
   study_params <- model$meta$fixed$data
@@ -403,8 +394,6 @@ standard_error.meta_bma <- standard_error.meta_random
 ci.meta_bma <- ci.meta_random
 
 
-
-
 # helper ------
 
 
@@ -422,7 +411,6 @@ ci.meta_bma <- ci.meta_random
 }
 
 
-
 # format_parameters -----------------------------------
 
 #' @export
