@@ -3,20 +3,20 @@
 #################### .mvord
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.mvord <- function(model,
                                    ci = 0.95,
-                                   component = c("all", "conditional", "thresholds", "correlation"),
+                                   component = "all",
                                    standardize = NULL,
                                    exponentiate = FALSE,
                                    p_adjust = NULL,
-                                   summary = getOption("parameters_summary", FALSE),
+                                   include_info = getOption("parameters_info", FALSE),
                                    keep = NULL,
                                    drop = NULL,
                                    verbose = TRUE,
                                    ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(component, c("all", "conditional", "thresholds", "correlation"))
+
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -29,7 +29,7 @@ model_parameters.mvord <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     ...
   )
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
