@@ -2,9 +2,9 @@
 model_parameters.stanfit <- function(model,
                                      centrality = "median",
                                      dispersion = FALSE,
-                                     ci = .95,
-                                     ci_method = "hdi",
-                                     test = c("pd", "rope"),
+                                     ci = 0.95,
+                                     ci_method = "eti",
+                                     test = "pd",
                                      rope_range = "default",
                                      rope_ci = 0.95,
                                      diagnostic = c("ESS", "Rhat"),
@@ -14,10 +14,8 @@ model_parameters.stanfit <- function(model,
                                      group_level = FALSE,
                                      keep = NULL,
                                      drop = NULL,
-                                     parameters = keep,
                                      verbose = TRUE,
                                      ...) {
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
@@ -40,13 +38,17 @@ model_parameters.stanfit <- function(model,
   )
 
   if (effects != "fixed") {
-    random_effect_levels <- which(params$Effects %in% "random" & grepl("^(?!Sigma\\[)(.*)", params$Parameter, perl = TRUE))
-    if (length(random_effect_levels) && isFALSE(group_level)) params <- params[-random_effect_levels, ]
+    random_effect_levels <- which(
+      params$Effects == "random" & !startsWith(params$Parameter, "Sigma[")
+    )
+    if (length(random_effect_levels) && isFALSE(group_level)) {
+      params <- params[-random_effect_levels, ]
+    }
   }
 
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    params <- .exponentiate_parameters(params, model, exponentiate)
-  }
+  # exponentiate coefficients and SE/CI, if requested
+  params <- .exponentiate_parameters(params, model, exponentiate)
+
   params <- .add_model_parameters_attributes(
     params,
     model,
@@ -58,8 +60,8 @@ model_parameters.stanfit <- function(model,
   )
 
   attr(params, "parameter_info") <- insight::clean_parameters(model)
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
-  class(params) <- c("parameters_stan", "parameters_model", "see_parameters_model", class(params))
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
+  class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
 }
