@@ -1,63 +1,3 @@
-#' Parameters from Bayesian Models
-#'
-#' Parameters from Bayesian models.
-#'
-#' @param model Bayesian model (including SEM from **blavaan**. May also be
-#'   a data frame with posterior samples, however, `as_draws` must be set to
-#'   `TRUE` (else, for data frames `NULL` is returned).
-#' @param ci Credible Interval (CI) level. Default to `0.95` (`95%`). See
-#'   [bayestestR::ci()] for further details.
-#' @param group_level Logical, for multilevel models (i.e. models with random
-#'   effects) and when `effects = "all"` or `effects = "random"`,
-#'   include the parameters for each group level from random effects. If
-#'   `group_level = FALSE` (the default), only information on SD and COR
-#'   are shown.
-#' @param component Which type of parameters to return, such as parameters for the
-#'   conditional model, the zero-inflation part of the model, the dispersion
-#'   term, or other auxiliary parameters be returned? Applies to models with
-#'   zero-inflation and/or dispersion formula, or if parameters such as `sigma`
-#'   should be included. May be abbreviated. Note that the *conditional*
-#'   component is also called *count* or *mean* component, depending on the
-#'   model. There are three convenient shortcuts: `component = "all"` returns
-#'   all possible parameters. If `component = "location"`, location parameters
-#'   such as `conditional`, `zero_inflated`, or `smooth_terms`, are returned
-#'   (everything that are fixed or random effects - depending on the `effects`
-#'   argument - but no auxiliary parameters). For `component = "distributional"`
-#'   (or `"auxiliary"`), components like `sigma`, `dispersion`, or `beta`
-#'   (and other auxiliary parameters) are returned.
-#' @param as_draws Logical, if `TRUE` and `model` is of class `data.frame`,
-#'   the data frame is treated as posterior samples and handled similar to
-#'   Bayesian models. All arguments in `...` are passed to
-#'   `model_parameters.draws()`.
-#' @inheritParams model_parameters.default
-#' @inheritParams bayestestR::describe_posterior
-#' @inheritParams insight::get_parameters
-#'
-#' @seealso [insight::standardize_names()] to
-#'   rename columns into a consistent, standardized naming scheme.
-#'
-#' @note When `standardize = "refit"`, columns `diagnostic`,
-#'   `bf_prior` and `priors` refer to the *original*
-#'   `model`. If `model` is a data frame, arguments `diagnostic`,
-#'   `bf_prior` and `priors` are ignored. \cr \cr There is also a
-#'   [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
-#'   implemented in the
-#'   [**see**-package](https://easystats.github.io/see/).
-#'
-#' @inheritSection model_parameters Confidence intervals and approximation of degrees of freedom
-#'
-#' @examples
-#' \donttest{
-#' library(parameters)
-#' if (require("rstanarm")) {
-#'   model <- suppressWarnings(stan_glm(
-#'     Sepal.Length ~ Petal.Length * Species,
-#'     data = iris, iter = 500, refresh = 0
-#'   ))
-#'   model_parameters(model)
-#' }
-#' }
-#' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters.stanreg <- function(model,
                                      centrality = "median",
@@ -78,6 +18,14 @@ model_parameters.stanreg <- function(model,
                                      drop = NULL,
                                      verbose = TRUE,
                                      ...) {
+  # for coef(), we don't need all the attributes and just stop here
+  if (effects %in% c("total", "random_total")) {
+    params <- .group_level_total(model)
+    params$Effects <- "total"
+    class(params) <- c("parameters_coef", "see_parameters_coef", class(params))
+    return(params)
+  }
+
   # Processing
   params <- .extract_parameters_bayesian(
     model,
@@ -101,7 +49,7 @@ model_parameters.stanreg <- function(model,
 
   if (effects != "fixed") {
     random_effect_levels <- which(
-      params$Effects %in% "random" & !startsWith(params$Parameter, "Sigma[")
+      params$Effects == "random" & !startsWith(params$Parameter, "Sigma[")
     )
     if (length(random_effect_levels) && isFALSE(group_level)) {
       params <- params[-random_effect_levels, , drop = FALSE]
