@@ -1,19 +1,22 @@
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.selection <- function(model,
                                        ci = 0.95,
-                                       component = c("all", "selection", "outcome", "auxiliary"),
+                                       component = "all",
                                        bootstrap = FALSE,
                                        iterations = 1000,
                                        standardize = NULL,
                                        exponentiate = FALSE,
                                        p_adjust = NULL,
-                                       summary = getOption("parameters_summary", FALSE),
+                                       include_info = getOption("parameters_info", FALSE),
                                        keep = NULL,
                                        drop = NULL,
                                        verbose = TRUE,
                                        ...) {
-  component <- match.arg(component)
+  component <- insight::validate_argument(
+    component,
+    c("all", "selection", "outcome", "auxiliary")
+  )
+
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -25,7 +28,7 @@ model_parameters.selection <- function(model,
     exponentiate = exponentiate,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     p_adjust = p_adjust,
     ...
   )
@@ -83,7 +86,6 @@ standard_error.selection <- function(model, component = c("all", "selection", "o
 }
 
 
-
 #' @export
 simulate_model.selection <- function(model,
                                      iterations = 1000,
@@ -100,10 +102,3 @@ simulate_model.selection <- function(model,
 
 #' @export
 ci.selection <- ci.default
-
-
-#' @export
-degrees_of_freedom.selection <- function(model, ...) {
-  s <- summary(model)
-  s$param$df
-}
