@@ -1,19 +1,16 @@
-
 #' @export
 model_parameters.sem <- model_parameters.default
 
 
-#' @export
-ci.sem <- ci.tobit
-
-
 #' @export
 standard_error.sem <- function(model, ...) {
   if (!.is_semLme(model)) {
     return(NULL)
   }
   if (is.null(model$se)) {
-    warning("Model has no standard errors. Please fit model again with bootstrapped standard errors.", call. = FALSE)
+    insight::format_alert(
+      "Model has no standard errors. Please fit model again with bootstrapped standard errors."
+    )
     return(NULL)
   }
   .data_frame(
@@ -23,8 +20,6 @@ standard_error.sem <- function(model, ...) {
 }
 
 
-#' @importFrom insight get_statistic
-#' @importFrom stats pnorm
 #' @export
 p_value.sem <- function(model, ...) {
   if (!.is_semLme(model)) {
