@@ -22,19 +22,10 @@ standard_error.vgam <- function(model, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.vgam <- function(model, ...) {
-  params <- insight::get_parameters(model)
-  out <- stats::setNames(rep(NA, nrow(params)), params$Parameter)
-  out[names(model@nl.df)] <- model@nl.df
-  out
-}
-
-
 #' @export
 p_value.vgam <- function(model, ...) {
   stat <- insight::get_statistic(model)
-  stat$p <- as.vector(stats::pchisq(stat$Statistic, df = degrees_of_freedom(model), lower.tail = FALSE))
+  stat$p <- as.vector(stats::pchisq(stat$Statistic, df = insight::get_df(model), lower.tail = FALSE))
 
   stat[c("Parameter", "p", "Component")]
 }
@@ -48,8 +39,6 @@ simulate_model.vgam <- function(model, iterations = 1000, ...) {
 }
 
 
-
-
 ########### .vglm ---------------
 
 
@@ -77,9 +66,6 @@ standard_error.vglm <- function(model, ...) {
 }
 
 
-
-
-
 # ci.vgam <- function(x, ci = 0.95, component = c("all", "conditional", "smooth"), ...) {
 #   component <- match.arg(component)
 #
