@@ -50,8 +50,6 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
 }
 
 
-
-
 # helper ------------------------------
 
 .p_value_dof <- function(model,
@@ -75,7 +73,7 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
   params <- insight::get_parameters(model, component = component)
 
   # check if all estimates are non-NA
-  params <- .check_rank_deficiency(params, verbose = FALSE)
+  params <- .check_rank_deficiency(model, params, verbose = FALSE)
 
   if (is.null(statistic)) {
     statistic <- insight::get_statistic(model, component = component)
@@ -88,7 +86,7 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
     if (is.null(se)) {
       se <- se_kenward(model)$SE
     }
-  } else if (!is.null(vcov) || isTRUE(list(...)[["robust"]])) {
+  } else if (!is.null(vcov)) {
     se <- standard_error(model,
       vcov = vcov,
       vcov_args = vcov_args,
@@ -121,8 +119,6 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
 }
 
 
-
-
 .p_value_dof_kr <- function(model, params, dof) {
   if ("SE" %in% colnames(params) && "SE" %in% colnames(dof)) {
     params$SE <- NULL
@@ -143,6 +139,6 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
   insight::check_if_installed("lme4")
 
   if (!(lme4::getME(model, "is_REML"))) {
-    warning(insight::format_message("Model was not fitted by REML. Re-fitting model now, but p-values, df, etc. still might be unreliable."), call. = FALSE)
+    insight::format_warning("Model was not fitted by REML. Re-fitting model now, but p-values, df, etc. still might be unreliable.")
   }
 }
