@@ -11,42 +11,49 @@
 #' @param select Determines which columns and and which layout columns are
 #' printed. There are three options for this argument:
 #'
-#' 1. Selecting columns by name or index
-#' \cr
-#'   `select` can be a character vector (or numeric index) of column names that
-#'   should be printed. There are two pre-defined options for selecting columns:
-#'   `select = "minimal"` prints coefficients, confidence intervals and p-values,
-#'   while `select = "short"` prints coefficients, standard errors and p-values.
+#' * **Selecting columns by name or index**
 #'
-#' 2. A string expression with layout pattern
-#' \cr
-#'   `select` is a string with "tokens" enclosed in braces. These tokens will
-#'   be replaced by their associated columns, where the selected columns will
-#'   be collapsed into one column. However, it is possible to create multiple
-#'   columns as well. Following tokens are replaced by the related coefficients
-#'   or statistics: `{estimate}`, `{se}`, `{ci}` (or `{ci_low}` and `{ci_high}`),
-#'   `{p}` and `{stars}`. The token `{ci}` will be replaced by `{ci_low}, {ci_high}`.
-#'   Furthermore, a `|` separates values into new cells/columns. If
-#'   `format = "html"`, a `<br>` inserts a line break inside a cell. See
+#'   `select` can be a character vector (or numeric index) of column names that
+#'   should be printed, where columns are extracted from the data frame returned
+#'   by `model_parameters()` and related functions.
+#'
+#'   There are two pre-defined options for selecting columns:
+#'   `select = "minimal"` prints coefficients, confidence intervals and
+#'   p-values, while `select = "short"` prints coefficients, standard errors and
+#'   p-values.
+#'
+#' * **A string expression with layout pattern**
+#'
+#'   `select` is a string with "tokens" enclosed in braces. These tokens will be
+#'   replaced by their associated columns, where the selected columns will be
+#'   collapsed into one column. Following tokens are replaced by the related
+#'   coefficients or statistics: `{estimate}`, `{se}`, `{ci}` (or `{ci_low}` and
+#'   `{ci_high}`), `{p}` and `{stars}`. The token `{ci}` will be replaced by
+#'   `{ci_low}, {ci_high}`. Example: `select = "{estimate}{stars} ({ci})"`
+#'
+#'   It is possible to create multiple columns as well. A `|` separates values
+#'   into new cells/columns. Example: `select = "{estimate} ({ci})|{p}"`.
+#'
+#'   If `format = "html"`, a `<br>` inserts a line break inside a cell. See
 #'   'Examples'.
 #'
-#' 3. A string indicating a pre-defined layout
-#' \cr
+#' * **A string indicating a pre-defined layout**
+#'
 #'   `select` can be one of the following string values, to create one of the
 #'   following pre-defined column layouts:
 #'
-#'     - `"ci"`: Estimates and confidence intervals, no asterisks for p-values.
-#'       This is equivalent to `select = "{estimate} ({ci})"`.
-#'     - `"se"`: Estimates and standard errors, no asterisks for p-values. This is
-#'       equivalent to `select = "{estimate} ({se})"`.
-#'     - `"ci_p"`: Estimates, confidence intervals and asterisks for p-values. This
-#'       is equivalent to `select = "{estimate}{stars} ({ci})"`.
-#'     - `"se_p"`: Estimates, standard errors and asterisks for p-values. This is
-#'       equivalent to `select = "{estimate}{stars} ({se})"`..
-#'     - `"ci_p2"`: Estimates, confidence intervals and numeric p-values, in two
-#'       columns. This is equivalent to `select = "{estimate} ({ci})|{p}"`.
-#'     - `"se_p2"`: Estimate, standard errors and numeric p-values, in two columns.
-#'       This is equivalent to `select = "{estimate} ({se})|{p}"`.
+#'   - `"ci"`: Estimates and confidence intervals, no asterisks for p-values.
+#'     This is equivalent to `select = "{estimate} ({ci})"`.
+#'   - `"se"`: Estimates and standard errors, no asterisks for p-values. This is
+#'     equivalent to `select = "{estimate} ({se})"`.
+#'   - `"ci_p"`: Estimates, confidence intervals and asterisks for p-values. This
+#'     is equivalent to `select = "{estimate}{stars} ({ci})"`.
+#'   - `"se_p"`: Estimates, standard errors and asterisks for p-values. This is
+#'     equivalent to `select = "{estimate}{stars} ({se})"`..
+#'   - `"ci_p2"`: Estimates, confidence intervals and numeric p-values, in two
+#'     columns. This is equivalent to `select = "{estimate} ({ci})|{p}"`.
+#'   - `"se_p2"`: Estimate, standard errors and numeric p-values, in two columns.
+#'     This is equivalent to `select = "{estimate} ({se})|{p}"`.
 #'
 #' For `model_parameters()`, glue-like syntax is still experimental in the
 #' case of more complex models (like mixed models) and may not return expected
@@ -92,8 +99,11 @@
 #'   categorical predictors. The coefficient for the reference level is always
 #'   `0` (except when `exponentiate = TRUE`, then the coefficient will be `1`),
 #'   so this is just for completeness.
+#' @param ... Arguments passed down to [`format.parameters_model()`],
+#'   [`insight::format_table()`] and [`insight::export_table()`]
 #' @inheritParams insight::format_table
 #' @inheritParams compare_parameters
+#' @inheritParams display.parameters_model
 #'
 #' @inheritSection format_parameters Interpretation of Interaction Terms
 #' @inheritSection model_parameters Labeling the Degrees of Freedom
@@ -104,13 +114,13 @@
 #' some messages providing additional information can be displayed or suppressed
 #' using `options()`:
 #'
-#' - `parameters_summary`: `options(parameters_summary = TRUE)` will override the
-#' `summary` argument in `model_parameters()` and always show the model summary
-#' for non-mixed models.
+#' - `parameters_info`: `options(parameters_info = TRUE)` will override the
+#' `include_info` argument in `model_parameters()` and always show the model
+#' summary for non-mixed models.
 #'
-#' - `parameters_mixed_summary`: `options(parameters_mixed_summary = TRUE)` will
-#' override the `summary` argument in `model_parameters()` for mixed models, and
-#' will then always show the model summary.
+#' - `parameters_mixed_info`: `options(parameters_mixed_info = TRUE)` will
+#' override the `include_info` argument in `model_parameters()` for mixed
+#' models, and will then always show the model summary.
 #'
 #' - `parameters_cimethod`: `options(parameters_cimethod = TRUE)` will show the
 #' additional information about the approximation method used to calculate
@@ -137,14 +147,27 @@
 #' default for the `select` argument. See argument's documentation for available
 #' options.
 #'
+#' - `easystats_table_width`: `options(easystats_table_width = <value>)` will
+#' set the default width for tables in text-format, i.e. for most of the outputs
+#' printed to console. If not specified, tables will be adjusted to the current
+#' available width, e.g. of the of the console (or any other source for textual
+#' output, like markdown files). The argument `table_width` can also be used in
+#' most `print()` methods to specify the table width as desired.
+#'
+#' - `easystats_html_engine`: `options(easystats_html_engine = "gt")` will set
+#' the default HTML engine for tables to `gt`, i.e. the _gt_ package is used to
+#' create HTML tables. If set to `tt`, the _tinytable_ package is used.
+#'
+#' - `insight_use_symbols`: `options(insight_use_symbols = TRUE)` will try to
+#' print unicode-chars for symbols as column names, wherever possible (e.g.,
+#' \ifelse{html}{\out{&omega;}}{\eqn{\omega}} instead of `Omega`).
+#'
 #' @details `summary()` is a convenient shortcut for
-#'   `print(object, select = "minimal", show_sigma = TRUE, show_formula = TRUE)`.
+#' `print(object, select = "minimal", show_sigma = TRUE, show_formula = TRUE)`.
 #'
 #' @return Invisibly returns the original input object.
 #'
-#' @seealso There is a dedicated method to use inside rmarkdown files,
-#'   [`print_md()`][print_md.parameters_model]. See also
-#'   [`display()`][display.parameters_model].
+#' @seealso See also [`display()`][display.parameters_model].
 #'
 #' @examplesIf require("gt", quietly = TRUE) && require("glmmTMB", quietly = TRUE)
 #' \donttest{
@@ -308,10 +331,10 @@ print.parameters_model <- function(x,
     footer <- ""
   }
   if (!identical(footer, "")) {
-    if (!is.null(footer)) {
-      footer <- paste0("\n", footer, "\n", footer_stats)
-    } else {
+    if (is.null(footer)) {
       footer <- footer_stats
+    } else {
+      footer <- paste0("\n", footer, "\n", footer_stats)
     }
   }
 
@@ -356,10 +379,13 @@ print.parameters_simulate <- print.parameters_model
 print.parameters_brms_meta <- print.parameters_model
 
 
-
-
 # Random effects ------------------
 
+#' @export
+print.parameters_coef <- function(x, ...) {
+  cat(insight::export_table(format(x, ...), ...))
+}
+
 #' @export
 print.parameters_random <- function(x, digits = 2, ...) {
   .print_random_parameters(x, digits = digits)
@@ -367,8 +393,6 @@ print.parameters_random <- function(x, digits = 2, ...) {
 }
 
 
-
-
 # helper --------------------
 
 .print_core <- function(x,
@@ -382,7 +406,7 @@ print.parameters_random <- function(x, digits = 2, ...) {
                         ci_width = "auto",
                         ci_brackets = TRUE,
                         format = "text",
-                        group = NULL,
+                        groups = NULL,
                         include_reference = FALSE,
                         ...) {
   format(
@@ -397,22 +421,20 @@ print.parameters_random <- function(x, digits = 2, ...) {
     ci_brackets = ci_brackets,
     zap_small = zap_small,
     format = format,
-    group = group,
+    groups = groups,
     include_reference = include_reference,
     ...
   )
 }
 
 
-
-
 .print_footer <- function(x,
                           digits = 3,
                           show_sigma = FALSE,
                           show_formula = FALSE,
                           format = "text") {
   # get attributes
-  sigma <- attributes(x)$sigma
+  model_sigma <- attributes(x)$sigma
   show_summary <- isTRUE(attributes(x)$show_summary)
   verbose <- .additional_arguments(x, "verbose", TRUE)
 
@@ -421,9 +443,10 @@ print.parameters_random <- function(x, digits = 2, ...) {
   show_sigma <- ifelse(show_summary, TRUE, show_sigma)
   show_formula <- ifelse(show_summary, TRUE, show_formula)
   show_r2 <- .additional_arguments(x, "show_summary", FALSE)
+  show_rmse <- .additional_arguments(x, "show_summary", FALSE)
 
   # set defaults, if necessary
-  if (is.null(sigma)) {
+  if (is.null(model_sigma)) {
     show_sigma <- FALSE
   }
 
@@ -434,13 +457,12 @@ print.parameters_random <- function(x, digits = 2, ...) {
     show_sigma = show_sigma,
     show_formula = show_formula,
     show_r2 = show_r2,
+    show_rmse = show_rmse,
     format = format
   )
 }
 
 
-
-
 .print_caption <- function(x, caption = NULL, format = "text") {
   no_caption <- attributes(x)$no_caption
   # no table-title for certain model tables, indicated by the no_caption attribute
@@ -499,8 +521,6 @@ print.parameters_random <- function(x, digits = 2, ...) {
 }
 
 
-
-
 #' @keywords internal
 .print_random_parameters <- function(random_params, digits = 2) {
   insight::print_color("# Random Effects\n\n", "blue")
@@ -522,10 +542,10 @@ print.parameters_random <- function(x, digits = 2, ...) {
   random_params$Term[is.na(random_params$Term)] <- ""
   random_params$SD[is.na(random_params$SD)] <- ""
 
-  non_empty <- random_params$Term != "" & random_params$Type != ""
+  non_empty <- random_params$Term != "" & random_params$Type != "" # nolint
   random_params$Line[non_empty] <- sprintf("%s (%s)", random_params$Type[non_empty], random_params$Term[non_empty])
 
-  non_empty <- random_params$Term != "" & random_params$Type == ""
+  non_empty <- random_params$Term != "" & random_params$Type == "" # nolint
   random_params$Line[non_empty] <- sprintf("%s", random_params$Term[non_empty])
 
   # final fix, indentions
@@ -561,17 +581,16 @@ print.parameters_random <- function(x, digits = 2, ...) {
 }
 
 
-
 .find_min_colwidth <- function(formatted_table) {
   shared_cols <- unique(unlist(lapply(formatted_table, colnames)))
   col_width <- rep(NA, length(shared_cols))
   for (i in seq_along(shared_cols)) {
     col_width[i] <- max(unlist(lapply(formatted_table, function(j) {
-      col <- j[[shared_cols[i]]]
-      if (!is.null(col)) {
-        max(nchar(col))
-      } else {
+      column <- j[[shared_cols[i]]]
+      if (is.null(column)) {
         NA
+      } else {
+        max(nchar(column))
       }
     })))
   }
