@@ -1,6 +1,6 @@
 # normal print ----------------------------
 
-#' @rdname display.parameters_model
+#' @rdname print.parameters_model
 #' @export
 print_html.parameters_model <- function(x,
                                         pretty_names = TRUE,
@@ -11,7 +11,7 @@ print_html.parameters_model <- function(x,
                                         footer = NULL,
                                         align = NULL,
                                         digits = 2,
-                                        ci_digits = 2,
+                                        ci_digits = digits,
                                         p_digits = 3,
                                         footer_digits = 3,
                                         ci_brackets = c("(", ")"),
@@ -22,6 +22,7 @@ print_html.parameters_model <- function(x,
                                         font_size = "100%",
                                         line_padding = 4,
                                         column_labels = NULL,
+                                        include_reference = FALSE,
                                         verbose = TRUE,
                                         ...) {
   # check if user supplied digits attributes
@@ -30,7 +31,7 @@ print_html.parameters_model <- function(x,
   }
 
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
 
   if (missing(p_digits)) {
@@ -45,6 +46,9 @@ print_html.parameters_model <- function(x,
   if (missing(select) || is.null(select)) {
     select <- attributes(x)$output_style
   }
+  if (missing(groups)) {
+    groups <- attributes(x)$parameter_groups
+  }
 
   # we need glue-like syntax right now...
   if (!is.null(select)) {
@@ -82,6 +86,7 @@ print_html.parameters_model <- function(x,
     ci_brackets = ci_brackets,
     format = "html",
     groups = groups,
+    include_reference = include_reference,
     ...
   )
 
@@ -133,13 +138,15 @@ print_html.parameters_simulate <- print_html.parameters_model
 #' @export
 print_html.parameters_sem <- print_html.parameters_model
 
+
+#' @rdname print.compare_parameters
 #' @export
 print_html.compare_parameters <- function(x,
                                           caption = NULL,
                                           subtitle = NULL,
                                           footer = NULL,
                                           digits = 2,
-                                          ci_digits = 2,
+                                          ci_digits = digits,
                                           p_digits = 3,
                                           zap_small = FALSE,
                                           groups = NULL,
@@ -148,6 +155,7 @@ print_html.compare_parameters <- function(x,
                                           font_size = "100%",
                                           line_padding = 4,
                                           column_labels = NULL,
+                                          engine = "gt",
                                           ...) {
   # check if user supplied digits attributes
   if (missing(digits)) {
@@ -155,7 +163,7 @@ print_html.compare_parameters <- function(x,
   }
 
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
 
   if (missing(p_digits)) {
@@ -167,6 +175,29 @@ print_html.compare_parameters <- function(x,
     select <- attributes(x)$output_style
   }
 
+  # markdown engine?
+  engine <- match.arg(getOption("easystats_html_engine", engine), c("gt", "default", "tt"))
+
+  # for tiny table, we can just call print_md()
+  if (engine == "tt") {
+    return(print_md(
+      x,
+      digits = digits,
+      ci_digits = ci_digits,
+      p_digits = p_digits,
+      caption = caption,
+      subtitle = subtitle,
+      footer = footer,
+      select = select,
+      split_components = TRUE,
+      ci_brackets = ci_brackets,
+      zap_small = zap_small,
+      groups = groups,
+      engine = "tt",
+      outformat = "html"
+    ))
+  }
+
   # we need glue-like syntax right now...
   select <- .convert_to_glue_syntax(style = select, "<br>")
 
@@ -184,6 +215,12 @@ print_html.compare_parameters <- function(x,
     groups = groups
   )
 
+  # replace brackets by parenthesis
+  if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
+    formatted_table$Parameter <- gsub("[", ci_brackets[1], formatted_table$Parameter, fixed = TRUE)
+    formatted_table$Parameter <- gsub("]", ci_brackets[2], formatted_table$Parameter, fixed = TRUE)
+  }
+
   out <- insight::export_table(
     formatted_table,
     format = "html",
@@ -206,7 +243,6 @@ print_html.compare_parameters <- function(x,
 }
 
 
-
 # helper ------------------
 
 .add_gt_options <- function(out,
@@ -231,7 +267,7 @@ print_html.compare_parameters <- function(x,
   if (!is.null(user_labels)) {
     new_labels <- c(
       colnames(out[["_data"]])[1],
-      rep(user_labels, length.out = ncol(out[["_data"]]) - 1)
+      rep_len(user_labels, ncol(out[["_data"]]) - 1)
     )
     new_labels <- as.list(new_labels)
   }
@@ -263,16 +299,18 @@ print_html.compare_parameters <- function(x,
     names(new_labels) <- colnames(out[["_data"]])
     out <- gt::cols_label(out, .list = new_labels)
   }
+  # find name of parameter column
+  pcol_name <- colnames(out[["_data"]])[1]
   # check where last parameter row ends. For "compare_models()", the
   # first Parameter value after data rows is "". If this is not found,
   # simply use number of rows as last row
-  last_row <- which(out[["_data"]]$Parameter == "")[1]
+  last_row <- which(!nzchar(as.character(out[["_data"]][[pcol_name]]), keepNA = TRUE))[1]
   if (is.na(last_row)) {
     last_row <- nrow(out[["_data"]])
   } else {
     last_row <- last_row - 1
   }
-  # add a border to the first column (Parameters)
+  # add a border to the first column.
   out <- gt::tab_style(
     out,
     style = gt::cell_borders(
@@ -281,7 +319,7 @@ print_html.compare_parameters <- function(x,
       color = "#d3d3d3"
     ),
     locations = gt::cells_body(
-      columns = "Parameter",
+      columns = pcol_name,
       rows = 1:last_row
     )
   )
