@@ -12,6 +12,14 @@ insight::supported_models
 #' @export
 insight::print_html
 
+#' @importFrom insight print_md
+#' @export
+insight::print_md
+
+#' @importFrom insight display
+#' @export
+insight::display
+
 # ----------------------- datawizard -------------------------------------
 
 #' @importFrom datawizard describe_distribution
@@ -26,29 +34,14 @@ datawizard::demean
 #' @export
 datawizard::rescale_weights
 
-#' @importFrom datawizard data_to_numeric
+#' @importFrom datawizard visualisation_recipe
 #' @export
-datawizard::data_to_numeric
-
-#' @importFrom datawizard convert_data_to_numeric
-#' @export
-datawizard::convert_data_to_numeric
-
-#' @importFrom datawizard skewness
-datawizard::skewness
+datawizard::visualisation_recipe
 
 #' @importFrom datawizard kurtosis
 #' @export
 datawizard::kurtosis
 
-#' @importFrom datawizard smoothness
+#' @importFrom datawizard skewness
 #' @export
-datawizard::smoothness
-
-#' @importFrom datawizard center
-#' @export
-datawizard::center
-
-#' @importFrom datawizard visualisation_recipe
-#' @export
-datawizard::visualisation_recipe
+datawizard::skewness
