@@ -11,9 +11,9 @@
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @return A data frame with information on each parameter (see
-#'   [parameters_type()]), and various standardization coefficients
-#'   for the post-hoc methods (see [standardize_parameters()]) for the predictor
-#'   and the response.
+#' [`parameters_type()`]), and various standardization coefficients
+#' for the post-hoc methods (see [`standardize_parameters()`]) for the predictor
+#' and the response.
 #'
 #' @family standardize
 #'
@@ -53,7 +53,7 @@ standardize_info.default <- function(model,
   # model_matrix <- as.data.frame(stats::model.matrix(model))
   model_matrix <- as.data.frame(insight::get_modelmatrix(model))
   model_data <- insight::get_data(model, source = "mf", verbose = FALSE)
-  wgts <- insight::get_weights(model, na_rm = TRUE)
+  wgts <- insight::get_weights(model, remove_na = TRUE)
 
   # validation check for ZI
   if (mi$is_zero_inflated && verbose) {
@@ -164,8 +164,6 @@ standardize_info.default <- function(model,
 }
 
 
-
-
 # Predictors - Smart ------------------------------------------------------------
 
 
@@ -204,7 +202,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 #' @keywords internal
 .std_info_predictor_smart <- function(data,
                                       variable,
@@ -295,9 +292,6 @@ standardize_info.default <- function(model,
 }
 
 
-
-
-
 # Predictors - sdy ------------------------------------------------------------
 
 
@@ -322,9 +316,6 @@ standardize_info.default <- function(model,
 }
 
 
-
-
-
 # Response ------------------------------------------------------------
 
 #' @keywords internal
@@ -372,7 +363,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 #' @keywords internal
 .std_info_response_basic <- function(model, info, params, robust = FALSE, w = NULL, ...) {
   if (inherits(model, c("gls", "lme"))) {
@@ -404,7 +394,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 # Pseudo (GLMM) -----------------------------------------------------------
 
 .std_info_pseudo <- function(model,
@@ -428,7 +417,7 @@ standardize_info.default <- function(model,
 
   within_vars <- unclass(performance::check_heterogeneity_bias(model))
   id <- insight::get_random(model)[[1]]
-  w <- insight::get_weights(model, na_rm = TRUE)
+  w <- insight::get_weights(model, remove_na = TRUE)
 
   ## Find which parameters vary on level 1 ("within")
   is_within <- logical(length = length(params))
@@ -552,7 +541,6 @@ standardize_info.default <- function(model,
 }
 
 
-
 # Utils -------------------------------------------------------------------
 
 
