@@ -267,9 +267,6 @@
 }
 
 
-
-
-
 # other helper ------------------------
 
 
@@ -371,13 +368,31 @@
 
   # check if we have model data, else return parameter table
   if (is.null(model_data)) {
-    params
+    return(params)
   }
 
   # find factors and factor levels and check if we have any factors in the data
   factors <- .find_factor_levels(model_data, model, model_call = attributes(params)$model_call)
   if (!length(factors)) {
-    params
+    # in case of "on-the-fly" factors, e.g.:
+    # m <- lm(mpg ~ cut(wt, c(0, 2.5, 3, 5)), data = mtcars)
+    # we need to receive the data from the model frame, in order to find factors
+    model_data <- insight::get_data(model, source = "mf", verbose = FALSE)
+    if (!is.null(model_data)) {
+      factors <- .find_factor_levels(model_data, model, model_call = attributes(params)$model_call)
+    }
+    # if we still didn't find anything, quit...
+    if (!length(factors)) {
+      return(params)
+    }
+  }
+  # next, check contrasts of factors. including the reference level makes
+  # only sense if there are contrasts that are all zeros, which means that
+  # the reference level is not included in the model matrix
+  remove_contrasts <- .remove_reference_contrasts(model)
+  # keep only factors with valid contrasts
+  if (!is.null(remove_contrasts) && length(remove_contrasts)) {
+    factors <- factors[setdiff(names(factors), remove_contrasts)]
   }
 
   # we need some more information about prettified labels etc.
@@ -430,6 +445,19 @@
       }
       # create a pretty level for the reference category
       pretty_level <- paste0(fn_clean, " [", sub(fn, "", reference_level, fixed = TRUE), "]")
+      pretty_level <- gsub("_", " ", pretty_level, fixed = TRUE)
+      # special handling for "cut()"
+      pattern_cut_right <- "(.*)\\((.*),(.*)\\]\\]$"
+      pattern_cut_left <- "(.*)\\[(.*),(.*)\\)\\]$"
+      if (all(grepl(pattern_cut_right, pretty_level))) {
+        lower_bounds <- gsub(pattern_cut_right, "\\2", pretty_level)
+        upper_bounds <- gsub(pattern_cut_right, "\\3", pretty_level)
+        pretty_level <- gsub(pattern_cut_right, paste0("\\1>", as.numeric(lower_bounds), "-", upper_bounds, "]"), pretty_level)
+      } else if (all(grepl(pattern_cut_left, pretty_level))) {
+        lower_bounds <- gsub(pattern_cut_left, "\\2", pretty_level)
+        upper_bounds <- gsub(pattern_cut_left, "\\3", pretty_level)
+        pretty_level <- gsub(pattern_cut_left, paste0("\\1", as.numeric(lower_bounds), "-<", upper_bounds, "]"), pretty_level)
+      }
       # insert new pretty level at the correct position in "pretty_names"
       pretty_names <- .insert_element_at(
         pretty_names,
@@ -483,7 +511,7 @@
   # brms random intercepts or random slope variances
   ran_sd <- startsWith(out$Parameter, "sd_") & out$Effects == "random"
   if (any(ran_sd)) {
-    out$Parameter[ran_sd] <- gsub("^sd_(.*?)__(.*)", "SD \\(\\2\\)", out$Parameter[ran_sd], perl = TRUE)
+    out$Parameter[ran_sd] <- gsub("^sd_(.*?)__(.*)", "SD \\(\\2\\)", out$Parameter[ran_sd])
     if (has_component) {
       ran_zi_sd <- ran_sd & out$Component == "zero_inflated"
       if (any(ran_zi_sd)) {
@@ -494,7 +522,7 @@
   # brms random slope-intercepts correlation
   ran_cor <- startsWith(out$Parameter, "cor_") & out$Effects == "random"
   if (any(ran_cor)) {
-    out$Parameter[ran_cor] <- gsub("^cor_(.*?)__(.*)__(.*)", "Cor \\(\\2~\\3\\)", out$Parameter[ran_cor], perl = TRUE)
+    out$Parameter[ran_cor] <- gsub("^cor_(.*?)__(.*)__(.*)", "Cor \\(\\2~\\3\\)", out$Parameter[ran_cor])
     if (has_component) {
       ran_zi_cor <- ran_cor & out$Component == "zero_inflated"
       if (any(ran_zi_cor)) {
@@ -523,7 +551,6 @@
 }
 
 
-
 # helper to format the header / subheader of different model components --------------
 
 .format_model_component_header <- function(x,
@@ -688,9 +715,6 @@
 }
 
 
-
-
-
 # helper grouping parameters -------------------
 
 
@@ -787,7 +811,6 @@
 }
 
 
-
 # .insert_row <- function(x, newrow, r) {
 #   existingDF[seq(r+1,nrow(existingDF)+1),] <- existingDF[seq(r,nrow(existingDF)),]
 #   existingDF[r,] <- newrow
@@ -861,8 +884,6 @@
 }
 
 
-
-
 .prepare_splitby_for_print <- function(x) {
   if (!is.null(attributes(x)$model_class) && any(attributes(x)$model_class == "mvord")) {
     x$Response <- NULL
@@ -888,8 +909,6 @@
 }
 
 
-
-
 # this function is actually similar to "insight::print_parameters()", but more
 # sophisticated, to ensure nicely outputs even for complicated or complex models,
 # or edge cases...
@@ -1185,8 +1204,6 @@
 }
 
 
-
-
 # helper to fix unequal number of columns for list of data frames,
 # when used for HTML printing
 
