@@ -10,7 +10,7 @@
                                              iterations = 1000,
                                              ci_method = NULL,
                                              p_adjust = NULL,
-                                             summary = FALSE,
+                                             include_info = FALSE,
                                              verbose = TRUE,
                                              group_level = FALSE,
                                              wb_component = FALSE,
@@ -51,10 +51,10 @@
   attr(params, "bootstrap") <- bootstrap
   attr(params, "iterations") <- iterations
   attr(params, "p_adjust") <- p_adjust
-  attr(params, "robust_vcov") <- isTRUE(list(...)$robust) || "vcov" %in% names(list(...))
+  attr(params, "robust_vcov") <- "vcov" %in% names(list(...))
   attr(params, "ignore_group") <- isFALSE(group_level)
   attr(params, "ran_pars") <- isFALSE(group_level)
-  attr(params, "show_summary") <- isTRUE(summary)
+  attr(params, "show_summary") <- isTRUE(include_info)
   attr(params, "log_link") <- isTRUE(grepl("log", info$link_function, fixed = TRUE))
   attr(params, "logit_link") <- isTRUE(identical(info$link_function, "logit"))
 
@@ -64,7 +64,7 @@
   # use tryCatch, these might fail...
   attr(params, "test_statistic") <- .safe(insight::find_statistic(model))
   attr(params, "log_response") <- .safe(isTRUE(grepl("log", insight::find_transformation(model), fixed = TRUE)))
-  attr(params, "log_predictors") <- .safe(any(grepl("log", unlist(insight::find_terms(model)[c("conditional", "zero_inflated", "instruments")]), fixed = TRUE))) # nolint
+  attr(params, "log_predictors") <- .safe(any(grepl("log", unlist(insight::find_terms(model, verbose = FALSE)[c("conditional", "zero_inflated", "instruments")]), fixed = TRUE))) # nolint
 
   # save if model is multivariate response model
   if (isTRUE(info$is_multivariate)) {
@@ -77,10 +77,12 @@
   }
 
 
-  # for summaries, add R2
-  if (isTRUE(summary) && requireNamespace("performance", quietly = TRUE)) {
+  # for additional infos, add R2, RMSE
+  if (isTRUE(include_info) && requireNamespace("performance", quietly = TRUE)) {
     rsq <- .safe(suppressWarnings(performance::r2(model)))
     attr(params, "r2") <- rsq
+    rmse <- .safe(performance::performance_rmse(model))
+    attr(params, "rmse") <- rmse
   }
 
 
@@ -98,14 +100,14 @@
 
   # weighted nobs
   weighted_nobs <- .safe({
-    w <- insight::get_weights(model, na_rm = TRUE, null_as_ones = TRUE)
+    w <- insight::get_weights(model, remove_na = TRUE, null_as_ones = TRUE)
     round(sum(w))
   })
   attr(params, "weighted_nobs") <- weighted_nobs
 
 
   # model formula
-  model_formula <- .safe(insight::safe_deparse(insight::find_formula(model)$conditional))
+  model_formula <- .safe(insight::safe_deparse(insight::find_formula(model, verbose = FALSE)$conditional)) # nolint
   attr(params, "model_formula") <- model_formula
 
 
@@ -255,7 +257,7 @@
         "Coefficient"
       )
     }
-  } else if (!is.null(info) && info$family != "unknown") {
+  } else if (!is.null(info) && info$family != "unknown" && !info$is_probit) {
     if (isTRUE(exponentiate)) {
       if (info$is_exponential && identical(info$link_function, "log")) {
         coef_col <- "Prevalence Ratio"
@@ -341,8 +343,6 @@
 }
 
 
-
-
 .add_pretty_names <- function(params, model) {
   attr(params, "model_class") <- class(model)
   cp <- insight::clean_parameters(model)
@@ -365,8 +365,6 @@
 }
 
 
-
-
 #' @keywords internal
 .add_anova_attributes <- function(params, model, ci, test = NULL, alternative = NULL, ...) {
   dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x) # nolint
@@ -418,7 +416,6 @@
 }
 
 
-
 .additional_arguments <- function(x, value, default) {
   add_args <- attributes(x)$additional_arguments
 
@@ -436,7 +433,6 @@
 }
 
 
-
 # checks for valid inputs in model_parameters(). E.g., some models don't support
 # the "vcov" argument - this should not be silently ignored, but rather the user
 # should be informed that robust SE are not available for that model.
@@ -456,7 +452,7 @@
       not_allowed_string <- datawizard::text_concatenate(not_allowed, enclose = "\"")
       insight::format_alert(
         sprintf("Following arguments are not supported in `%s()` for models of class `%s` and will be ignored: %s", function_name, model_class, not_allowed_string), # nolint
-        sprintf("Please run `%s()` again without specifying the above mentioned arguments to obtain expected results.", function_name) # nolint
+        sprintf("In case you obtain expected results, please run `%s()` again without specifying the above mentioned arguments.", function_name) # nolint
       )
     }
     dots[not_allowed] <- NULL
@@ -468,7 +464,6 @@
 }
 
 
-
 # functions to check if necessary default argument was provided ------------
 
 .is_model_valid <- function(model) {
