@@ -67,8 +67,6 @@ get_scores <- function(x, n_items = NULL) {
 }
 
 
-
-
 # model parameters -----------------------------------------------------------------
 
 
@@ -89,10 +87,6 @@ model_parameters.parameters_efa <- function(model, ...) {
 model_parameters.parameters_pca <- model_parameters.parameters_efa
 
 
-
-
-
-
 # summary -----------------------------------------------------------------
 
 
@@ -132,11 +126,6 @@ summary.parameters_omega <- function(object, ...) {
 }
 
 
-
-
-
-
-
 # predict -----------------------------------------------------------------
 
 
@@ -178,7 +167,7 @@ predict.parameters_efa <- function(object,
     out <- as.matrix(newdata) %*% as.matrix(attri$model$loadings)
     out <- stats::setNames(as.data.frame(out), paste0("Component", seq_len(ncol(out))))
   } else if (inherits(attri$model, c("psych", "fa", "principal"))) {
-    out <- as.data.frame(stats::predict(attri$model, data = newdata, ...))
+    out <- as.data.frame(stats::predict(attri$model, data = newdata[rownames(attri$model$weights)], ...))
   } else {
     out <- as.data.frame(stats::predict(attri$model, newdata = newdata, ...))
   }
@@ -194,8 +183,6 @@ predict.parameters_efa <- function(object,
 predict.parameters_pca <- predict.parameters_efa
 
 
-
-
 .merge_na <- function(object, out, verbose = TRUE) {
   compl_cases <- attributes(object)$complete_cases
   if (is.null(compl_cases)) {
@@ -214,10 +201,6 @@ predict.parameters_pca <- predict.parameters_efa
 }
 
 
-
-
-
-
 # print -------------------------------------------------------------------
 
 
@@ -298,10 +281,6 @@ print.parameters_omega_summary <- function(x, ...) {
 }
 
 
-
-
-
-
 # print-helper ----------------------
 
 
@@ -352,19 +331,25 @@ print.parameters_omega_summary <- function(x, ...) {
     footer <- c(.text_components_variance(x, sep = ifelse(format == "markdown", "", "\n")), "yellow")
   }
 
+  # alignment?
+  if (is.null(labels)) {
+    alignment <- NULL
+  } else {
+    alignment <- paste(c("ll", rep("r", ncol(x) - 2)), collapse = "")
+  }
+
   insight::export_table(
     x,
     digits = digits,
     format = format,
     caption = table_caption,
     footer = footer,
-    align = "firstleft",
+    align = alignment,
     ...
   )
 }
 
 
-
 #' @keywords internal
 .text_components_variance <- function(x, sep = "") {
   type <- attributes(x)$type
@@ -424,10 +409,6 @@ print.parameters_omega_summary <- function(x, ...) {
 }
 
 
-
-
-
-
 # sort --------------------------------------------------------------------
 
 #' @rdname principal_components
@@ -488,9 +469,6 @@ sort.parameters_pca <- sort.parameters_efa
 }
 
 
-
-
-
 # Filter --------------------------------------------------------------------
 
 
@@ -520,7 +498,6 @@ sort.parameters_pca <- sort.parameters_efa
 }
 
 
-
 # closest_component -------------------------------------------------------
 
 
@@ -535,7 +512,6 @@ closest_component <- function(pca_results) {
 }
 
 
-
 .closest_component <- function(loadings, loadings_columns = NULL, variable_names = NULL) {
   if (is.matrix(loadings)) loadings <- as.data.frame(loadings)
   if (is.null(loadings_columns)) loadings_columns <- seq_len(ncol(loadings))
