@@ -1,16 +1,14 @@
-skip_if_not_installed("marginaleffects", minimum_version = "0.18.0")
+skip_if_not_installed("marginaleffects", minimum_version = "0.25.0")
 skip_if_not_installed("rstanarm")
 
 test_that("marginaleffects()", {
   # Frequentist
   x <- lm(Sepal.Width ~ Species * Petal.Length, data = iris)
-  model <- marginaleffects::avg_slopes(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
+  model <- marginaleffects::avg_slopes(x, newdata = insight::get_datagrid(x, by = "Species"), variables = "Petal.Length")
   out <- parameters(model)
   expect_identical(nrow(out), 1L)
-  expect_named(out, c(
-    "Parameter", "Coefficient", "SE", "Statistic",
-    "p", "s.value", "CI", "CI_low", "CI_high"
-  ))
+  cols <- c("Parameter", "Comparison", "Coefficient", "SE", "Statistic", "p", "S", "CI", "CI_low", "CI_high")
+  expect_true(all(cols %in% colnames(out)))
   out <- model_parameters(model, exponentiate = TRUE)
   expect_equal(out$Coefficient, 1.394, tolerance = 1e-3)
 
@@ -24,7 +22,7 @@ test_that("marginaleffects()", {
       chains = 1
     )
   )
-  model <- marginaleffects::avg_slopes(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
+  model <- marginaleffects::avg_slopes(x, newdata = insight::get_datagrid(x, by = "Species"), variables = "Petal.Length")
   expect_identical(nrow(parameters(model)), 1L)
 })
 
@@ -35,8 +33,8 @@ test_that("predictions()", {
   out <- parameters(p)
   expect_identical(nrow(out), 3L)
   expect_named(out, c(
-    "Predicted", "SE", "CI", "CI_low", "CI_high", "Statistic",
-    "p", "Species", "s.value"
+    "Predicted", "SE", "CI", "CI_low", "CI_high", "S", "Statistic",
+    "p", "Species"
   ))
   out <- parameters(p, exponentiate = TRUE)
   expect_equal(out$Predicted, c(30.81495, 15.95863, 19.57004), tolerance = 1e-4)
@@ -47,7 +45,7 @@ test_that("comparisons()", {
   data(iris)
   # Frequentist
   x <- lm(Sepal.Width ~ Species * Petal.Length, data = iris)
-  m <- marginaleffects::avg_comparisons(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
+  m <- marginaleffects::avg_comparisons(x, newdata = insight::get_datagrid(x, by = "Species"), variables = "Petal.Length")
   expect_identical(nrow(parameters(m)), 1L)
   out <- parameters(m, exponentiate = TRUE)
   expect_equal(out$Coefficient, 1.393999, tolerance = 1e-4)
@@ -64,14 +62,13 @@ test_that("comparisons()", {
   )
   m <- marginaleffects::avg_slopes(
     x,
-    newdata = insight::get_datagrid(x, at = "Species"),
+    newdata = insight::get_datagrid(x, by = "Species"),
     variables = "Petal.Length"
   )
   expect_identical(nrow(parameters(m)), 1L)
 })
 
 
-
 test_that("hypotheses()", {
   data(mtcars)
   x <- lm(mpg ~ hp + wt, data = mtcars)
@@ -87,7 +84,7 @@ test_that("multiple contrasts: Issue #779", {
   cmp <- suppressWarnings(marginaleffects::comparisons(
     mod,
     variables = c("gear", "cyl"),
-    newdata = insight::get_datagrid(mod, at = c("gear", "cyl")),
+    newdata = insight::get_datagrid(mod, by = c("gear", "cyl")),
     cross = TRUE
   ))
   cmp <- suppressWarnings(parameters(cmp))
@@ -104,3 +101,30 @@ test_that("model_parameters defaults to FALSE: Issue #916", {
   out2 <- model_parameters(pred, exponentiate = FALSE)
   expect_equal(out1$Predicted, out2$Predicted, tolerance = 1e-4)
 })
+
+
+test_that("digits and ci_digits for marginaleffects", {
+  data(mtcars)
+  skip_if(getRversion() < "4.2.0")
+  out <- lm(mpg ~ wt, data = mtcars) |>
+    marginaleffects::hypotheses(hypothesis = "10*wt = 0") |>
+    model_parameters(digits = 1)
+  expect_snapshot(out)
+})
+
+
+test_that("preserve columns with same name as reserved words", {
+  data(mtcars)
+  skip_if(getRversion() < "4.2.0")
+  skip_if_not_installed("modelbased")
+
+  set.seed(1234)
+  x <- rnorm(200)
+  z <- rnorm(200)
+  # quadratic relationship
+  y <- 2 * x + x^2 + 4 * z + rnorm(200)
+  d <- data.frame(x, y, z)
+  model <- lm(y ~ x + z, data = d)
+  pred <- modelbased::estimate_means(model, c("x", "z"))
+  expect_named(pred, c("x", "z", "Mean", "SE", "CI_low", "CI_high", "t", "df"))
+})
