@@ -1,3 +1,5 @@
+skip_on_os("linux")
+
 test_that("model_parameters.BFBayesFactor", {
   skip_on_cran()
   skip("TODO")
@@ -82,7 +84,7 @@ test_that("model_parameters.BFBayesFactor", {
     centrality = "mean",
     dispersion = TRUE,
     verbose = FALSE,
-    effectsize_type = "cramers_v",
+    es_type = "cramers_v",
     adjust = TRUE,
     include_proportions = TRUE
   ))
@@ -156,7 +158,7 @@ test_that("model_parameters.BFBayesFactor, with effectsize", {
   skip_if_not_installed("BayesFactor")
   set.seed(123)
   df_t_es <- as.data.frame(
-    parameters(BayesFactor::ttestBF(mtcars$wt, mu = 3), effectsize_type = "cohens_d")
+    parameters(BayesFactor::ttestBF(mtcars$wt, mu = 3), es_type = "cohens_d")
   )
 
   # TODO: fix column order
