@@ -16,7 +16,7 @@ skip_on_cran()
 test_that("p_value", {
   skip_if_not_installed("curl")
   skip_if_offline()
-  skip_if_not_installed("httr")
+  skip_if_not_installed("httr2")
   skip_if_not_installed("lme4")
 
   # h-tests
@@ -77,28 +77,27 @@ test_that("p_value", {
 
   # ANOVA lmer
   model <- insight::download_model("anova_lmerMod_0")
-  expect_equal(p_value(model), NA)
+  expect_identical(p_value(model), NA)
 
   model <- insight::download_model("anova_lmerMod_1")
-  expect_equal(p_value(model), NA)
+  expect_identical(p_value(model), NA)
 
   model <- insight::download_model("anova_lmerMod_2")
-  expect_equal(p_value(model), NA)
+  expect_identical(p_value(model), NA)
 
   model <- insight::download_model("anova_lmerMod_3")
-  expect_equal(p_value(model), NA)
+  expect_identical(p_value(model), NA)
 
   model <- insight::download_model("anova_lmerMod_4")
-  expect_equal(p_value(model), NA)
+  expect_identical(p_value(model), NA)
 
   model <- insight::download_model("anova_lmerMod_5")
-  expect_equal(p_value(model), NA)
+  expect_identical(p_value(model), NA)
 
   model <- insight::download_model("anova_lmerMod_6")
   expect_equal(p_value(model)$p[2], 0, tolerance = 0.01)
 
 
-
   # Mixed models
   model <- lme4::lmer(wt ~ cyl + (1 | gear), data = mtcars)
   expect_equal(p_value(model)$p[1], 0.206219, tolerance = 0.01)
