@@ -3,7 +3,7 @@ skip_if_not_installed("withr")
 skip_if(getRversion() < "4.0.0")
 
 withr::with_options(
-  list(parameters_interaction = "*"),
+  list(parameters_interaction = "*", easystats_table_width = Inf),
   {
     # Splitting model components ----
     test_that("print model with multiple components", {
@@ -25,7 +25,7 @@ withr::with_options(
       # snapshot breaks between R CMD check "classic" and "strict"
       skip_if_not_installed("performance")
       model <- lm(Sepal.Length ~ Species * Petal.Length, data = iris)
-      out <- model_parameters(model, summary = TRUE)
+      out <- model_parameters(model, include_info = TRUE)
       expect_snapshot(print(out))
     })
 
@@ -111,12 +111,20 @@ withr::with_options(
 
 withr::with_options(
   list(parameters_warning_exponentiate = TRUE),
-  {
-    test_that("message about interpretation of log-resoponse", {
-      data(mtcars)
-      m <- lm(log(mpg) ~ gear, data = mtcars)
-      out <- model_parameters(m, exponentiate = TRUE)
-      expect_snapshot(print(out))
-    })
-  }
+  test_that("no more message about interpretation of log-resoponse", {
+    data(mtcars)
+    m <- lm(log(mpg) ~ gear, data = mtcars)
+    out <- model_parameters(m, exponentiate = TRUE)
+    expect_snapshot(print(out))
+  })
+)
+
+withr::with_options(
+  list(parameters_warning_exponentiate = TRUE),
+  test_that("no fail for mgcv-binomial", {
+    skip_if_not_installed("mgcv")
+    m <- mgcv::gam(vs ~ s(mpg), data = mtcars, family = "binomial")
+    out <- model_parameters(m)
+    expect_snapshot(print(out))
+  })
 )
